@@ -5,7 +5,7 @@
 #undef HAVE_STPCPY
 #undef HAVE_ODBC
 #undef HAVE_MYSQL
-#undef HAVE_INTERBASE
+#undef HAVE_FIREBIRD
 #undef HAVE_LDAP
 #undef HAVE_MDB
 #undef HAVE_ORACLE
@@ -19,5 +19,6 @@
 #undef HAVE_POSTGRES
 #undef HAVE_CAMEL
 #undef HAVE_SQLITE
+#undef HAVE_XBASE
 #undef GETTEXT_PACKAGE
 #undef BONOBO_EXPLICIT_TRANSLATION_DOMAIN
