@@ -30,13 +30,13 @@ GdaServerProvider *plugin_create_provider (void);
 const gchar *
 plugin_get_name (void)
 {
-	return "Xbase (dBase III/IV, Clipper, FoxPro)";
+	return "Xbase";
 }
 
 const gchar *
 plugin_get_description (void)
 {
-	return _("Provider for Xbase databases");
+	return _("Provider for Xbase (dBase, FoxPro, etc) files");
 }
 
 GList *
@@ -44,8 +44,14 @@ plugin_get_connection_params (void)
 {
 	GList *list = NULL;
 
-	list = g_list_append (list, g_strdup ("FILENAME"));
-	list = g_list_append (list, g_strdup ("DIRECTORY"));
+	list = g_list_append (list,
+			      gda_provider_parameter_info_new_full ("FILENAME", _("File Name"),
+								    _("Full path of the file containing the database"),
+								    GDA_VALUE_TYPE_STRING));
+	list = g_list_append (list,
+			      gda_provider_parameter_info_new_full ("DIRECTORY", _("Directory"),
+								    _("Directory containing the xBase files"),
+								    GDA_VALUE_TYPE_STRING));
 
 	return list;
 }
